Learn R Programming

enviPick (version 1.2)

enviPickwrap: Peak detection for LC-HRMS .mzML and .mzXML data

Description

A wrapper combining data upload, partitioning, EIC clustering and EIC peak detection from readMSdata, mzagglom, mzclust and mzpick.

Usage

enviPickwrap(filepath.mzXML, MSlevel=c(1), dmzgap=15, dmzdens=4, ppm=TRUE, 
drtgap=500, drtsmall=20, drtdens=250, drtfill=10, drttotal=200, minpeak=4,  
recurs=3, weight=2, SB=3, SN=2, minint=1E5, maxint=1E7, ended=2, progbar=FALSE)

Arguments

filepath.mzXML
Path to the .mzXML file to be read, readMSdata
MSlevel
numeric 1 (MS) or 2 (MS-MS), readMSdata
dmzgap
m/z gap width for partitioning, mzpart
dmzdens
Maximum measurement deviation (+/-) of m/z within an EIC, mzclust
ppm
dmzgap, given in ppm (TRUE) or as absolute value (FALSE)
drtgap
RT gap width for partitioning, mzpart
drtsmall
Peak definition - RT window of a peak; cp. minpeak argument
drtdens
Maximum length of EICs, mzclust
drtfill
RT gap length to be filled, mzpick
drttotal
Maximum RT length of a single peak, mzpick
minpeak
Peak definition - minimum number of measurements per peak to found in windows of drtsmall and dmzsmall, mzpick
recurs
Maximum number of peaks within one EIC, mzpick
weight
Weight for assigning measurements to a peak, mzpick
SB
Signal-to-base ratio, mzpick
SN
Signal-to-noise ratio, mzpick
minint
Minimum intensity of a peak, mzpick
maxint
Peaks above this intensity are alwas included, regardless of checks for SB or SN,mzpick
ended
Within the peak detection recursion set by argument recurs, how often can a peak detection fail, to end the recursion? mzpick
progbar
Show a progress bar (TRUE or FALSE)? May only work under Windows OS.

Value

  • MSlist
  • StateMSlist[[1]]: tags the individual steps the MSlist has undergone for peak picking.
  • ParametersMSlist[[2]]: saves the parameter settings.
  • ResultsMSlist[[3]]: saves the result summary values
  • ScansMSlist[[4]]: matrix with raw measurements (m/z, intensity, RT) and tags for partitions, EIC cluster or individual peaks.
  • Partition_IndexMSlist[[5]]: Index assigning partitions to sections in the raw measurment of MSlist[[4]]. Required for fast (random) access, e.g., plotting.
  • EIC_indexMSlist[[6]]: Index assigning EIC clusters to sections in the raw measurment of MSlist[[4]]. Required for fast access.
  • Peak_indexMSlist[[7]]: Index assigning picked peaks to sections in the raw measurment of MSlist[[4]]. Required for fast access.
  • PeaklistMSlist[[8]]: Final peak list, cp. mzpick

Details

For further details on the parameter settings, please refer to the arguments of the underlying functions readMSdata, mzagglom, mzclust and mzpick.

See Also

readMSdata mzagglom mzclust mzpick plotMSlist